@@ -15,9 +15,6 @@ use ipnetwork::IpNetwork;
 use crate::spf::validate::{SpfRfcStandard, SpfValidationResult};
 use std::{convert::TryFrom, str::FromStr};
 
-/// This is the maximnum number of characters that an Spf Record can store.
-const MAX_SPF_STRING_LENGTH: usize = 255;
-
 /// The definition of the Spf struct which contains all information related a single
 /// SPF record.
 #[derive(Debug)]
@@ -38,6 +35,8 @@ pub struct Spf {
     was_parsed: bool,
     was_validated: bool,
     is_valid: bool,
+    #[allow(dead_code)]
+    warnings: Option<Vec<String>>,
 }
 
 impl std::fmt::Display for Spf {
@@ -65,13 +64,14 @@ impl Default for Spf {
             was_parsed: false,
             was_validated: false,
             is_valid: false,
+            warnings: None,
         }
     }
 }
 
-/// Creates an `Spf Stuct` by parsing a spf string.
+/// Creates an `Spf Struct` by parsing a string representation of Spf.
 ///
-/// # examples
+/// # Examples:
 ///
 ///```rust
 /// use decon_spf::Spf;
@@ -86,6 +86,15 @@ impl Default for Spf {
 /// let err: SpfError = bad_input.to_string().parse::<Spf>().unwrap_err();
 /// assert_eq!(err.to_string(), SpfError::WhiteSpaceSyntaxError.to_string());
 /// //  err.to_string() -> "Spf contains two or more consecutive whitespace characters.");
+///
+/// // Example with warn-dns feature enabled.
+/// // Spf contains an invalid DNS host entry
+/// let bad_spf2: Spf = "v=spf1 a mx:example.m/24 -all".parse().unwrap();
+/// // Note: `warn-dns` will check `example.m` ignoring `/24`
+/// #[cfg(feature = "warn-dns")]
+/// assert_eq!(bad_spf2.has_warnings(), true);
+/// #[cfg(feature = "warn-dns")]
+/// assert_eq!(bad_spf2.warnings().unwrap()[0], "example.m/24");
 ///```
 ///
 impl FromStr for Spf {
@@ -95,10 +104,10 @@ impl FromStr for Spf {
         if !source.starts_with("v=spf1") && !source.starts_with("spf2.0") {
             return Err(SpfError::InvalidSource);
         };
-        if source.len() > MAX_SPF_STRING_LENGTH {
+        if source.len() > helpers::MAX_SPF_STRING_LENGTH {
             return Err(SpfError::SourceLengthExceeded);
         };
-        if helpers::spf_has_consecutive_whitespace(source.as_str()) {
+        if helpers::spf_check_whitespace(source.as_str()) {
             return Err(SpfError::WhiteSpaceSyntaxError);
         };
         // Basic Checks are ok.
@@ -111,19 +120,44 @@ impl FromStr for Spf {
         let mut vec_of_a: Vec<Mechanism<String>> = Vec::new();
         let mut vec_of_mx: Vec<Mechanism<String>> = Vec::new();
         let mut vec_of_exists: Vec<Mechanism<String>> = Vec::new();
+        #[cfg(feature = "warn-dns")]
+        let mut vec_of_warnings: Vec<String> = Vec::new();
         for record in records {
             // Consider ensuring we do this once at least and then skip
             if record.contains("v=spf1") || record.starts_with("spf2.0") {
                 spf.version = record.to_string();
             } else if record.contains("redirect=") {
                 // Match a redirect
-                spf.redirect = Some(Mechanism::<String>::from_str(record).unwrap());
-                spf.is_redirected = true;
+                if let Ok(redirect) = Mechanism::<String>::from_str(record) {
+                    #[cfg(feature = "warn-dns")]
+                    {
+                        if !helpers::dns_is_valid(&redirect.raw()) {
+                            vec_of_warnings.push(redirect.raw());
+                        }
+                    }
+                    spf.redirect = Some(redirect);
+                    spf.is_redirected = true;
+                }
             } else if record.contains("include:") {
-                // Match an include
-                vec_of_includes.push(Mechanism::<String>::from_str(record).unwrap());
+                if let Ok(include) = Mechanism::<String>::from_str(record) {
+                    #[cfg(feature = "warn-dns")]
+                    {
+                        if !helpers::dns_is_valid(&include.raw()) {
+                            vec_of_warnings.push(include.raw());
+                        }
+                    }
+                    vec_of_includes.push(include);
+                }
             } else if record.contains("exists:") {
-                vec_of_exists.push(Mechanism::<String>::from_str(record).unwrap());
+                if let Ok(exists) = Mechanism::<String>::from_str(record) {
+                    #[cfg(feature = "warn-dns")]
+                    {
+                        if !helpers::dns_is_valid(&exists.raw()) {
+                            vec_of_warnings.push(exists.raw());
+                        }
+                    }
+                    vec_of_exists.push(exists);
+                }
             } else if record.contains("ip4:") {
                 // Match an ip4
                 let qualifier_and_modified_str = helpers::return_and_remove_qualifier(record, 'i');
@@ -155,10 +189,36 @@ impl FromStr for Spf {
                 spf.all = Some(Mechanism::<String>::from_str(record).unwrap());
             // Handle A, MX and PTR types.
             } else if let Some(a_mechanism) = helpers::capture_matches(record, Kind::A) {
+                #[cfg(feature = "warn-dns")]
+                {
+                    if !a_mechanism.raw().starts_with('/')
+                        && !helpers::dns_is_valid(helpers::get_domain_before_slash(
+                            &a_mechanism.raw(),
+                        ))
+                    {
+                        vec_of_warnings.push(a_mechanism.raw());
+                    }
+                }
                 vec_of_a.push(a_mechanism);
             } else if let Some(mx_mechanism) = helpers::capture_matches(record, Kind::MX) {
+                #[cfg(feature = "warn-dns")]
+                {
+                    if !mx_mechanism.raw().starts_with('/')
+                        && !helpers::dns_is_valid(helpers::get_domain_before_slash(
+                            &mx_mechanism.raw(),
+                        ))
+                    {
+                        vec_of_warnings.push(mx_mechanism.raw());
+                    }
+                }
                 vec_of_mx.push(mx_mechanism);
             } else if let Some(ptr_mechanism) = helpers::capture_matches(record, Kind::Ptr) {
+                #[cfg(feature = "warn-dns")]
+                {
+                    if !helpers::dns_is_valid(&ptr_mechanism.raw()) {
+                        vec_of_warnings.push(ptr_mechanism.raw());
+                    }
+                }
                 spf.ptr = Some(ptr_mechanism);
             }
         }
@@ -181,6 +241,13 @@ impl FromStr for Spf {
         if !vec_of_exists.is_empty() {
             spf.exists = Some(vec_of_exists);
         }
+        #[cfg(feature = "warn-dns")]
+        {
+            if !vec_of_warnings.is_empty() {
+                spf.warnings = Some(vec_of_warnings);
+            }
+        }
+
         spf.was_parsed = true;
         spf.is_valid = true;
         spf.source = source;
@@ -212,6 +279,14 @@ impl Spf {
         };
         false
     }
+    /// Check if there were any warnings when parsing the Spf String.
+    /// This can only be changed to `true` when `warn-dns` feature has been eabled. Other wise it
+    /// will always be `false`
+    #[cfg_attr(docsrs, doc(cfg(feature = "warn-dns")))]
+    #[cfg(feature = "warn-dns")]
+    pub fn has_warnings(&self) -> bool {
+        !self.warnings.is_none()
+    }
     /// Set version to `v=spf1`
     pub fn set_v1(&mut self) {
         self.version = String::from("v=spf1");
@@ -356,7 +431,7 @@ impl Spf {
     /// ```
     ///
     /// # Note:
-    /// If The Spf is already set as `Redirect` trying to append an `All`
+    /// If the Spf is already set as `Redirect` trying to append an `All`
     /// Mechanism will have no affect.
     // Consider make this a Result
     pub fn append_mechanism(&mut self, mechanism: Mechanism<String>) {
@@ -401,10 +476,10 @@ impl Spf {
     /// - Will fail if there are more than 10 DNS lookups. Looks are required for each `A`, `MX`
     /// , `Redirect`, and `Include` Mechanism. See: [`LookupLimitExceeded`](SpfError::LookupLimitExceeded)
     /// (This will change given new information)
-    #[deprecated(note = "This is expected to be deprecated.")]
+    #[deprecated(note = "This is expected to be depreciated.")]
     pub fn try_validate(&mut self) -> Result<(), SpfError> {
         if self.from_src {
-            if self.source.len() > MAX_SPF_STRING_LENGTH {
+            if self.source.len() > helpers::MAX_SPF_STRING_LENGTH {
                 return Err(SpfError::SourceLengthExceeded);
             } else if !self.was_parsed {
                 return Err(SpfError::HasNotBeenParsed);
@@ -440,27 +515,27 @@ impl Spf {
     fn build_spf_string(&self) -> String {
         let mut spf = String::new();
         spf.push_str(self.version());
-        if self.a().is_some() {
-            spf.push_str(helpers::build_spf_str(self.a()).as_str());
+        if let Some(a) = self.a() {
+            spf.push_str(helpers::build_spf_str(a).as_str());
         };
-        if self.mx().is_some() {
-            spf.push_str(helpers::build_spf_str(self.mx()).as_str());
+        if let Some(mx) = self.mx() {
+            spf.push_str(helpers::build_spf_str(mx).as_str());
         };
-        if self.includes().is_some() {
-            spf.push_str(helpers::build_spf_str(self.includes()).as_str());
+        if let Some(includes) = self.includes() {
+            spf.push_str(helpers::build_spf_str(includes).as_str());
         }
-        if self.ip4().is_some() {
-            spf.push_str(helpers::build_spf_str_from_ip(self.ip4()).as_str());
+        if let Some(ip4) = self.ip4() {
+            spf.push_str(helpers::build_spf_str_from_ip(ip4).as_str());
         }
-        if self.ip6().is_some() {
-            spf.push_str(helpers::build_spf_str_from_ip(self.ip6()).as_str());
+        if let Some(ip6) = self.ip6() {
+            spf.push_str(helpers::build_spf_str_from_ip(ip6).as_str());
         }
-        if self.exists().is_some() {
-            spf.push_str(helpers::build_spf_str(self.exists()).as_str());
+        if let Some(exists) = self.exists() {
+            spf.push_str(helpers::build_spf_str(exists).as_str());
         }
-        if self.ptr().is_some() {
+        if let Some(ptr) = self.ptr() {
             spf.push(' ');
-            spf.push_str(self.ptr().unwrap().to_string().as_str());
+            spf.push_str(ptr.to_string().as_str());
         }
         if self.is_redirected {
             spf.push(' ');
@@ -527,4 +602,10 @@ impl Spf {
     pub fn all(&self) -> Option<&Mechanism<String>> {
         self.all.as_ref()
     }
+    /// Return a reference to the list of domains that gave warnings.
+    #[cfg_attr(docsrs, doc(cfg(feature = "warn-dns")))]
+    #[cfg(feature = "warn-dns")]
+    pub fn warnings(&self) -> Option<&Vec<String>> {
+        self.warnings.as_ref()
+    }
 }
